#!/usr/bin/env python

metadata = {
    'name': 'splarnektity',
    'version': '0.3',
    'description': 'Functional Pattern Matching for Python',
    'author': 'David Baird',
    'author_email': 'dhbaird@gmail.com',
    'url': 'http://www.aclevername.com/projects/splarnektity',
    'py_modules': ['splarnektity'],
    'long_description': \
'''Splarnektity provides a limited, but valuable, form of functional pattern
matching to Python, a la OCaml, Erlang, Haskell, et al..  Another way
of thinking of this is: pattern matching over Python lists.


Here is a quick example of Splarnektity's usage::

    from splarnektity import FMatch

    sexpr = ('person',
                ('name', 'john'),
                ('address', ('line1', '123 Townville'), ('zip', 54321)),
                ('age', 24),
                ('favorite foods', 'pizza', 'dorritos'),
            )

    for x in sexpr[1:]:
        f = FMatch(x)
        V1, V2 = f.var(2)
        if f.when(('name', V1)):
            print 'name:          ', V1.v
        elif f.when(('address', ('line1', V1), ('zip', V2))) and V2.int:
            print 'address line1: ', V1.v
            print 'address zip:   ', V2.v
        elif f.when(('age', V1)) and V1.int:
            print 'age:           ', V1.v
        elif f.when(('favorite foods', V1.others)): # variable length matching
            print 'favorite foods:', V1.v

The result of this example is::

    name:           john
    address line1:  123 Townville
    address zip:    54321
    age:            24
    favorite foods: ('pizza', 'dorritos')
''',
    'classifiers': [
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
    ],
    'keywords': 'functional pattern matching python',
    #'license'='BSD',
    #'install_requires'=[], # yay! no prerequisites!
}

if __name__ == '__main__':
    #from distutils.core import setup
    from setuptools import setup # this allows: python build.py bdist_egg
    # WARNING: "python setup.py sdist" does not work on AFS.
    #          (due to hardlinks).  The following hack was found on the
    #          distutils mailing list 2005-August:
    import os
    delattr(os, 'link') # remove the ability to do hardlinks
    setup(**metadata)
